SciPy
=====

:Release: |release|
:Date: |today|

SciPy (pronounced "Sigh Pie") is open-source software for mathematics,
science, and engineering.

.. toctree::
   :maxdepth: 1

   release
   api

Tutorial
--------

Tutorials with worked examples and background information for most SciPy
submodules.

.. toctree::
   :maxdepth: 2

   tutorial/index.rst

Developer's Guide
-----------------

Explanations of how to start contributing to SciPy, and descriptions of
maintenance activities and policies.

.. toctree::
   :maxdepth: 1

   hacking
   dev/index

API Reference
-------------

The exact API of all functions and classes, as given by the docstrings. The API
documents expected types and allowed features for all functions, and all
parameters available for the algorithms.

.. toctree::
   :maxdepth: 1

   cluster
   constants
   fftpack
   integrate
   interpolate
   io
   linalg
   misc
   ndimage
   odr
   optimize
   signal
   sparse
   sparse.linalg
   sparse.csgraph
   spatial
   special
   stats
   stats.mstats
   weave
